@@ -1,8 +1,8 @@
 ;;
 ; following functions are implemented within C
-;  rk-find-seq
-;  rk-find-partial-seq
-;  rk-expect-seq
+;  rk-lib-find-seq
+;  rk-lib-find-partial-seq
+;  rk-lib-expect-seq
 ;
 ; back match is mainly used for Hangul
 
@@ -17,11 +17,10 @@
       (rk-context-set-back-match! res back)
       res)))
 
-;;
+;; accessor
 (define rk-context-rule
   (lambda (rkc)
     (car (nthcdr 0 rkc))))
-;;
 (define rk-context-set-rule!
   (lambda (rkc rule)
     (set-car! (nthcdr 0 rkc) rule)))
@@ -39,30 +38,32 @@
 (define rk-context-set-immediate-commit!
   (lambda (rkc flag)
     (set-car! (nthcdr 2 rkc) flag)))
+
 (define rk-context-back-match
   (lambda (rkc)
     (car (nthcdr 3 rkc))))
 (define rk-context-set-back-match!
   (lambda (rkc flag)
     (set-car! (nthcdr 3 rkc) flag)))
-;;
+
+;; back match
 (define rk-find-longest-back-match
   (lambda (rule seq)
     (if seq
-	(if (rk-find-seq seq rule)
+	(if (rk-lib-find-seq seq rule)
 	    seq
 	    (rk-find-longest-back-match rule (cdr seq)))
 	nil)))
-;;
+;; back match
 (define rk-find-longest-head
   (lambda (rseq rule)
     (let ((seq (reverse rseq)))
-      (if (rk-find-seq seq rule)
+      (if (rk-lib-find-seq seq rule)
 	  seq
 	  (if rseq
 	      (rk-find-longest-head (cdr rseq) rule)
 	      nil)))))
-;;
+;; back match
 (define rk-check-back-commit
   (lambda (rkc rule rseq)
     (let* ((seq (reverse rseq))
@@ -72,13 +73,13 @@
 	   (head
 	    (truncate-list seq
 			   (- (length seq) (length longest-tail))))
-	   (partial (rk-find-partial-seq seq rule))
+	   (partial (rk-lib-find-partial-seq seq rule))
 	   (tail-partial
 	    (if longest-tail
-		(rk-find-partial-seq longest-tail rule)
+		(rk-lib-find-partial-seq longest-tail rule)
 		nil))
-	   (c (rk-find-seq longest-tail rule))
-	   (t (rk-find-seq seq rule))
+	   (c (rk-lib-find-seq longest-tail rule))
+	   (t (rk-lib-find-seq seq rule))
 	   (res ()))
       (and
        (if (> len 0)
@@ -92,7 +93,7 @@
 	   #t)
        (if (not tail-partial)
 	   (begin
-	     (set! res (cadr (rk-find-seq longest-head rule)))
+	     (set! res (cadr (rk-lib-find-seq longest-head rule)))
 	     (rk-context-set-seq!
 	      rkc
 	      (reverse
@@ -102,13 +103,13 @@
 	     #f)
 	   #t)
        (begin
-	 (set! res (cadr (rk-find-seq head rule)))
+	 (set! res (cadr (rk-lib-find-seq head rule)))
 	 (rk-context-set-seq! rkc (reverse longest-tail))))
       res)))
 ;;
 (define rk-partial-seq?
   (lambda (rkc s)
-    (rk-find-partial-seq
+    (rk-lib-find-partial-seq
      (reverse s) (rk-context-rule rkc))))
 ;; API
 (define rk-partial?
@@ -124,12 +125,14 @@
   (lambda (rkc)
     (let* ((s (rk-context-seq rkc))
 	   (rule (rk-context-rule rkc)))
-      (rk-find-seq (reverse s) rule))))
+      (rk-lib-find-seq (reverse s) rule))))
 
+;; API
 (define rk-flush
   (lambda (context)
     (rk-context-set-seq! context ())))
 
+;; API
 (define rk-backspace
   (lambda (context)
     (if
@@ -140,6 +143,7 @@
        #t)
      #f)))
  
+;; API
 (define rk-delete
   (lambda (context)
     (if
@@ -150,11 +154,12 @@
        #t)
      #f)))
 
+;; front match
 (define rk-proc-tail
   (lambda (context seq)
     (let* ((rule (rk-context-rule context))
 	   (old-seq
-	    (rk-find-seq
+	    (rk-lib-find-seq
 	     (reverse (rk-context-seq context)) rule))
 	   (res nil))
       (if old-seq
@@ -179,14 +184,15 @@
 	(begin
 	  (rk-context-set-seq! context s)
 	  nil))))
-;;
+;; API
 (define rk-expect
   (lambda (rkc)
     (let
 	((s (reverse (rk-context-seq rkc)))
 	 (rule (rk-context-rule rkc)))
-      (rk-expect-seq s rule))))
-;;
+      (rk-lib-expect-seq s rule))))
+
+;; back match
 (define rk-push-key-back-match
   (lambda (rkc key)
     (let*
@@ -197,13 +203,14 @@
       (rk-context-set-seq! rkc new-seq)
       (rk-check-back-commit rkc rule new-seq))))
 
+;; front match
 (define rk-push-key-front-match
   (lambda (rkc key)
     (let*
 	((s (rk-context-seq rkc))
 	 (s (cons key s))
 	 (rule (rk-context-rule rkc))
-	 (seq (rk-find-seq (reverse s) rule))
+	 (seq (rk-lib-find-seq (reverse s) rule))
 	 (res))
       (set!
        res
@@ -223,7 +230,7 @@
     (let*
 	((s (rk-context-seq rkc))
 	 (rule (rk-context-rule rkc))
-	 (seq (rk-find-seq (reverse s) rule)))
+	 (seq (rk-lib-find-seq (reverse s) rule)))
       (rk-proc-end-seq rkc seq s)
       )))
 
