@@ -455,7 +455,9 @@
 	     (skk-commit-raw sc id key key-state)
 	     #f)
 	   #t)
-       (if (= key skk-latin-conv-key)
+       (if (and
+	    (string-equal? (rk-pending rkc) "")
+	    (= key skk-latin-conv-key))
 	   (begin
 	     (skk-context-set-state! sc 'skk-state-kanji)
 	     (skk-update-mode id sc)
@@ -788,7 +790,8 @@
 	     (skk-update-prop-label sc id)
 	     #f)
 	   #t)
-       (if (modifier-key-mask key-state)
+       (if (and (modifier-key-mask key-state)
+		(not (shift-key-mask key-state)))
 	   (begin
 	     (skk-commit-raw sc id key key-state)
 	     #f)
