@@ -20,6 +20,13 @@ static char uim_help_buf[BUFFER_SIZE];
 /*Common buffer for some functions's temporary buffer.
   Pay attention for use.*/
 
+char*
+get_server_command(void)
+{
+  return "uim-helper-server";
+}
+
+
 int uim_helper_init_client_fd(void (*disconnect_cb)(void))
 {
     int fd;
@@ -44,10 +51,28 @@ int uim_helper_init_client_fd(void (*disconnect_cb)(void))
     }
 
     if(connect(fd,&server,sizeof(server)) == -1){
-      perror("failed to connect to server");
-      return -1;
+      int serv_pid = 0;
+      FILE *serv_r = NULL, *serv_w = NULL;
+      char buf[128];
+
+      serv_pid = uim_ipc_open_command(serv_pid, &serv_r, &serv_w, get_server_command());
+
+      if(serv_pid == 0) {
+	return -1;
+      }
+
+      while (fgets (buf, sizeof(buf), serv_r ) != NULL ) {
+	if(strcmp( buf, "\n" ) == 0)
+	  break;
+      }
+
+      if(connect(fd,&server,sizeof(server)) == -1){
+	return -1;
+      }
     }
 
+    uim_disconnect_cb = disconnect_cb;
+
     uim_fd = fd;
     return fd;
 }
@@ -103,8 +128,9 @@ uim_helper_read_proc(int fd)
     
     rc = read(fd, buf, sizeof(buf)-1);
     
-    if(rc == 0) {
+    if(rc == 0 && uim_disconnect_cb) {
       uim_disconnect_cb();
+      uim_fd = -1;
       return tmp;
     }
     
