@@ -220,6 +220,9 @@ main(int argc, char **argv)
   printf("waiting\n\n");
   fflush(stdout);
 
+  fclose(stdin);
+  fclose(stdout);
+
   if (serv_fd < 0) {
     return 0;
   }
